#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 X11-xft
version:              0.3.1
visibility:           public
id:                   X11-xft-0.3.1-HCIlXgFW6xyIVhjwXQV6if
key:                  X11-xft-0.3.1-HCIlXgFW6xyIVhjwXQV6if
license:              LicenseRef-LGPL
maintainer:           clemens@endorphin.org
author:               Clemens Fruhwirth
synopsis:
    Bindings to the Xft, X Free Type interface library, and some Xrender parts

description:
    Bindings to the Xft, X Free Type interface library, and some Xrender parts

category:             Graphics
abi:                  c2a08e805eefc33292db7d344e1e2733
exposed:              True
exposed-modules:      Graphics.X11.Xft Graphics.X11.Xrender
import-dirs:          /usr/lib/ghc-8.10.5/site-local/X11-xft-0.3.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/X11-xft-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/X11-xft-0.3.1
hs-libraries:         HSX11-xft-0.3.1-HCIlXgFW6xyIVhjwXQV6if
extra-libraries:      Xft
include-dirs:
    /usr/include/freetype2 /usr/include/libpng16 /usr/include/harfbuzz
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include

depends:
    X11-1.10-HbpsQ2GV6c9KOqYJVkRlFu base-4.14.2.0
    utf8-string-1.0.2-DMovLmOdbFr3ZT2kNNb9Du

haddock-interfaces:   /usr/share/doc/haskell-x11-xft/html/X11-xft.haddock
haddock-html:         /usr/share/doc/haskell-x11-xft/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

